@@ -3,7 +3,7 @@
 
 #if defined(_MSC_VER) && (_MSC_VER < 1600) // for MS Visual Studio prior to 2010
 typedef unsigned __int32 uint32_t;
-#elif defined(__linux__) || defined(__GLIBC__) || defined(__WIN32__) || defined(_MSC_VER) || defined(__APPLE__)
+#elif defined(__linux__) || defined(__GLIBC__) || defined(__WIN32__) || defined(_MSC_VER) || defined(__APPLE__) || defined(__GNU__)
 #include <stdint.h>
 #elif defined(__osf__)
 #include <inttypes.h>
@@ -25,5 +25,6 @@ uint32_t mt_get_seed(struct mt *self);
 void mt_init_seed(struct mt *self, uint32_t seed);
 void mt_setup_array(struct mt *self, uint32_t *array, int n);
 double mt_genrand(struct mt *self);
+uint32_t mt_genirand(struct mt *self);
 
 #endif
